@@ -4,9 +4,6 @@
 #include <gtk/gtk.h>
 #include "zenity.h"
 
-#ifdef GDK_WINDOWING_X11
-#include <gdk/gdkx.h>
-#endif
 
 G_BEGIN_DECLS
 
@@ -19,20 +16,20 @@ GtkBuilder*     zenity_util_load_ui_file                  (const gchar    *widge
 gchar *         zenity_util_strip_newline                 (gchar          *string);
 gboolean        zenity_util_fill_file_buffer              (GtkTextBuffer  *buffer, 
                                                            const gchar    *filename);
-const gchar *   zenity_util_stock_from_filename		  (const gchar    *filename);
+const gchar *   zenity_util_icon_name_from_filename	  (const gchar    *filename);
 void		zenity_util_set_window_icon		  (GtkWidget      *widget,
 							   const gchar	  *filename,
 							   const gchar	  *default_file);
-void            zenity_util_set_window_icon_from_stock    (GtkWidget      *widget,
+void            zenity_util_set_window_icon_from_icon_name(GtkWidget      *widget,
 							   const gchar    *filename,
-                                                           const gchar    *default_stock_id);
-GdkPixbuf *	zenity_util_pixbuf_new_from_file	  (GtkWidget	  *widget,
+                                                           const gchar    *default_icon_name);
+void		zenity_util_set_window_icon_from_file	  (GtkWidget	  *widget,
 							   const gchar	  *filename);
 void		zenity_util_show_help                     (GError        **error);
 gint		zenity_util_return_exit_code 		  (ZenityExitCode value);                      
 void            zenity_util_exit_code_with_data           (ZenityExitCode value,
                                                            ZenityData     *data);
-void            zenity_util_show_dialog                   (GtkWidget      *widget, Window parent);
+void            zenity_util_show_dialog                   (GtkWidget      *widget, guintptr parent);
 
 gboolean        zenity_util_timeout_handle                (gpointer data);
 
